@@ -275,9 +275,9 @@ was not originally documented and it is not tested.  However, there
 appeared to be no other method for obtaining a header structure from
 a file, so I figured I would write a small bit of documentation on it.
 
-=head2 Bad Value Support
+=head1 Bad Value Support
 
-As of PDL-2.4.8, L<PDL::IO::FlexRaw> has support for reading and writing
+As of PDL-2.4.8, L<PDL::IO::FlexRaw|PDL::IO::FlexRaw> has support for reading and writing
 pdls with L<bad|PDL::Bad> values in them.
 
 On C<writeflex>, a piddle
@@ -305,7 +305,7 @@ reference the current C<$hdr> looks like this:
     
     $badpdl = readflex('badpdl', [$hdr]);
 
-If you use bad values and try the new L<PDL::IO::FlexRaw> bad value
+If you use bad values and try the new L<PDL::IO::FlexRaw|PDL::IO::FlexRaw> bad value
 support, please let us know via the perldl mailing list.
 Suggestions and feedback are also welcome.
 
